==> nvpy-2.1.0.tar.gz: nvpy-2.1.0/nvpy/bindings.py <==
description = '''\
============= ==========
Key combo     Action
============= ==========
Ctrl-?        Display these key-bindings.
Ctrl-A        Select all text when in the note editor.
Ctrl-D        Move note to trash. This can be easily recovered using the
              simplenote webapp.
Ctrl-F        Start real-time incremental regular expression search. As you type,
              notes list is filtered. Up / down cursor keys go to
              previous / next note.
Ctrl-G        Edit tags for currently selected note. Press ESC to return to note
              editing.
Ctrl-J        Navigate (down) to next note in list. (VIM binding)
Ctrl-K        Navigate (up) to previous note in list. (VIM binding)
Ctrl-M        Render Markdown note to HTML and open browser window.
Ctrl-N        Create new note.
Ctrl-Q        Exit nvPY.
Ctrl-R        Render reStructuredText (reST) note to HTML and open browser window.
Ctrl-S        Force sync of current note with simplenote server. Saving to disc
              and syncing to server also happen continuously in the background
Ctrl-Shift-S  Toggle a pinned button.
Ctrl-Y        Redo note edits.
Ctrl-Z        Undo note edits.
Ctrl-SPACE    In search box, autocomplete tag under cursor. Keep on pressing for more alternatives.
Ctrl-+/-      Increase or decrease the font size.
Ctrl-BS       Delete previous word in the note editor.
Ctrl-Delete   Delete next word in the note editor.
ESC           Go from edit mode to notes list.
Ctrl-[        Same as ESC. (VIM binding)
ENTER         Start editing currently selected note. If there's a search string but
              no notes in the list, ENTER creates a new note with that search
              string as its title.
'''

==> nvpy-2.2.0.tar.gz: nvpy-2.2.0/nvpy/bindings.py <==
description = '''\
============= ==========
Key combo     Action
============= ==========
Ctrl-?        Display these key-bindings.
Ctrl-A        Select all text when in the note editor.
Ctrl-C        Copy selected text into the clipboard. If no text is selected, copy the note title.
Ctrl-D        Move note to trash. This can be easily recovered using the
              simplenote webapp.
Ctrl-F        Start real-time incremental regular expression search. As you type,
              notes list is filtered. Up / down cursor keys go to
              previous / next note.
Ctrl-G        Edit tags for currently selected note. Press ESC to return to note
              editing.
Ctrl-J        Navigate (down) to next note in list. (VIM binding)
Ctrl-K        Navigate (up) to previous note in list. (VIM binding)
Ctrl-M        Render Markdown note to HTML and open browser window.
Ctrl-N        Create new note.
Ctrl-Q        Exit nvPY.
Ctrl-R        Render reStructuredText (reST) note to HTML and open browser window.
Ctrl-S        Force sync of current note with simplenote server. Saving to disc
              and syncing to server also happen continuously in the background
Ctrl-Shift-S  Toggle a pinned button.
Ctrl-Y        Redo note edits.
Ctrl-Z        Undo note edits.
Ctrl-SPACE    In search box, autocomplete tag under cursor. Keep on pressing for more alternatives.
Ctrl-+/-      Increase or decrease the font size.
Ctrl-BS       Delete previous word in the note editor.
Ctrl-Delete   Delete next word in the note editor.
ESC           Go from edit mode to search box (and, optionally, in empty search box, exit nvPY).
Ctrl-[        Same as ESC. (VIM binding)
ENTER         Start editing currently selected note. If there's a search string but
              no notes in the list, ENTER creates a new note with that search
              string as its title.
'''
